@@ -67,7 +67,7 @@
 
 
 /* First part of user prologue.  */
-#line 1 "../rcfile_y.y"
+#line 1 "rcfile_y.y"
 
 /*
  * rcfile_y.y -- Run control file parser for fetchmail
@@ -367,7 +367,7 @@ extern int yydebug;
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 union YYSTYPE
 {
-#line 57 "../rcfile_y.y"
+#line 57 "rcfile_y.y"
 
   int proto;
   int number;
@@ -1409,7 +1409,7 @@ yydestruct (const char *yymsg,
   switch (yykind)
     {
     case 63: /* STRING  */
-#line 85 "../rcfile_y.y"
+#line 85 "rcfile_y.y"
             { free (((*yyvaluep).sval)); }
 #line 1415 "rcfile_y.c"
         break;
@@ -1690,181 +1690,181 @@ yyreduce:
   switch (yyn)
     {
   case 8:
-#line 100 "../rcfile_y.y"
+#line 100 "rcfile_y.y"
                                                 {run.logfile = prependdir ((yyvsp[0].sval), rcfiledir); free((yyvsp[0].sval));}
 #line 1696 "rcfile_y.c"
     break;
 
   case 9:
-#line 101 "../rcfile_y.y"
+#line 101 "rcfile_y.y"
                                                 {run.idfile = prependdir ((yyvsp[0].sval), rcfiledir); free((yyvsp[0].sval));}
 #line 1702 "rcfile_y.c"
     break;
 
   case 10:
-#line 102 "../rcfile_y.y"
+#line 102 "rcfile_y.y"
                                                 {run.pidfile = prependdir ((yyvsp[0].sval), rcfiledir); free((yyvsp[0].sval));}
 #line 1708 "rcfile_y.c"
     break;
 
   case 11:
-#line 103 "../rcfile_y.y"
+#line 103 "rcfile_y.y"
                                                 {run.poll_interval = (yyvsp[0].number);}
 #line 1714 "rcfile_y.c"
     break;
 
   case 12:
-#line 104 "../rcfile_y.y"
+#line 104 "rcfile_y.y"
                                                 {run.postmaster = (yyvsp[0].sval);}
 #line 1720 "rcfile_y.c"
     break;
 
   case 13:
-#line 105 "../rcfile_y.y"
+#line 105 "rcfile_y.y"
                                                 {run.bouncemail = TRUE;}
 #line 1726 "rcfile_y.c"
     break;
 
   case 14:
-#line 106 "../rcfile_y.y"
+#line 106 "rcfile_y.y"
                                                 {run.bouncemail = FALSE;}
 #line 1732 "rcfile_y.c"
     break;
 
   case 15:
-#line 107 "../rcfile_y.y"
+#line 107 "rcfile_y.y"
                                                 {run.spambounce = TRUE;}
 #line 1738 "rcfile_y.c"
     break;
 
   case 16:
-#line 108 "../rcfile_y.y"
+#line 108 "rcfile_y.y"
                                                 {run.spambounce = FALSE;}
 #line 1744 "rcfile_y.c"
     break;
 
   case 17:
-#line 109 "../rcfile_y.y"
+#line 109 "rcfile_y.y"
                                                 {run.softbounce = TRUE;}
 #line 1750 "rcfile_y.c"
     break;
 
   case 18:
-#line 110 "../rcfile_y.y"
+#line 110 "rcfile_y.y"
                                                 {run.softbounce = FALSE;}
 #line 1756 "rcfile_y.c"
     break;
 
   case 19:
-#line 111 "../rcfile_y.y"
+#line 111 "rcfile_y.y"
                                                 {run.properties = (yyvsp[0].sval);}
 #line 1762 "rcfile_y.c"
     break;
 
   case 20:
-#line 112 "../rcfile_y.y"
+#line 112 "rcfile_y.y"
                                                 {run.use_syslog = TRUE;}
 #line 1768 "rcfile_y.c"
     break;
 
   case 21:
-#line 113 "../rcfile_y.y"
+#line 113 "rcfile_y.y"
                                                 {run.use_syslog = FALSE;}
 #line 1774 "rcfile_y.c"
     break;
 
   case 22:
-#line 114 "../rcfile_y.y"
+#line 114 "rcfile_y.y"
                                                 {run.invisible = TRUE;}
 #line 1780 "rcfile_y.c"
     break;
 
   case 23:
-#line 115 "../rcfile_y.y"
+#line 115 "rcfile_y.y"
                                                 {run.invisible = FALSE;}
 #line 1786 "rcfile_y.c"
     break;
 
   case 24:
-#line 116 "../rcfile_y.y"
+#line 116 "rcfile_y.y"
                                                 {run.showdots = FLAG_TRUE;}
 #line 1792 "rcfile_y.c"
     break;
 
   case 25:
-#line 117 "../rcfile_y.y"
+#line 117 "rcfile_y.y"
                                                 {run.showdots = FLAG_FALSE;}
 #line 1798 "rcfile_y.c"
     break;
 
   case 26:
-#line 125 "../rcfile_y.y"
+#line 125 "rcfile_y.y"
                                                         {record_current();}
 #line 1804 "rcfile_y.c"
     break;
 
   case 28:
-#line 130 "../rcfile_y.y"
+#line 130 "rcfile_y.y"
                         {yyerror(GT_("server option after user options"));}
 #line 1810 "rcfile_y.c"
     break;
 
   case 29:
-#line 133 "../rcfile_y.y"
+#line 133 "rcfile_y.y"
                                         {reset_server((yyvsp[0].sval), FALSE); free((yyvsp[0].sval));}
 #line 1816 "rcfile_y.c"
     break;
 
   case 30:
-#line 134 "../rcfile_y.y"
+#line 134 "rcfile_y.y"
                                         {reset_server((yyvsp[0].sval), TRUE);  free((yyvsp[0].sval));}
 #line 1822 "rcfile_y.c"
     break;
 
   case 31:
-#line 135 "../rcfile_y.y"
+#line 135 "rcfile_y.y"
                                         {reset_server("defaults", FALSE);}
 #line 1828 "rcfile_y.c"
     break;
 
   case 34:
-#line 142 "../rcfile_y.y"
+#line 142 "rcfile_y.y"
                                         {save_str(&current.server.akalist,(yyvsp[0].sval),0); free((yyvsp[0].sval));}
 #line 1834 "rcfile_y.c"
     break;
 
   case 35:
-#line 143 "../rcfile_y.y"
+#line 143 "rcfile_y.y"
                                         {save_str(&current.server.akalist,(yyvsp[0].sval),0); free((yyvsp[0].sval));}
 #line 1840 "rcfile_y.c"
     break;
 
   case 36:
-#line 146 "../rcfile_y.y"
+#line 146 "rcfile_y.y"
                                         {save_str(&current.server.localdomains,(yyvsp[0].sval),0); free((yyvsp[0].sval));}
 #line 1846 "rcfile_y.c"
     break;
 
   case 37:
-#line 147 "../rcfile_y.y"
+#line 147 "rcfile_y.y"
                                         {save_str(&current.server.localdomains,(yyvsp[0].sval),0); free((yyvsp[0].sval));}
 #line 1852 "rcfile_y.c"
     break;
 
   case 39:
-#line 151 "../rcfile_y.y"
+#line 151 "rcfile_y.y"
                                         {current.server.via = (yyvsp[0].sval);}
 #line 1858 "rcfile_y.c"
     break;
 
   case 41:
-#line 153 "../rcfile_y.y"
+#line 153 "rcfile_y.y"
                                         {current.server.protocol = (yyvsp[0].proto);}
 #line 1864 "rcfile_y.c"
     break;
 
   case 42:
-#line 154 "../rcfile_y.y"
+#line 154 "rcfile_y.y"
                                         {
 					    current.server.protocol = P_POP3;
 
@@ -1880,25 +1880,25 @@ yyreduce:
     break;
 
   case 43:
-#line 165 "../rcfile_y.y"
+#line 165 "rcfile_y.y"
                                         {current.server.principal = (yyvsp[0].sval);}
 #line 1886 "rcfile_y.c"
     break;
 
   case 44:
-#line 166 "../rcfile_y.y"
+#line 166 "rcfile_y.y"
                                         {current.server.esmtp_name = (yyvsp[0].sval);}
 #line 1892 "rcfile_y.c"
     break;
 
   case 45:
-#line 167 "../rcfile_y.y"
+#line 167 "rcfile_y.y"
                                         {current.server.esmtp_password = (yyvsp[0].sval);}
 #line 1898 "rcfile_y.c"
     break;
 
   case 46:
-#line 168 "../rcfile_y.y"
+#line 168 "rcfile_y.y"
                                         {
 #ifdef SDPS_ENABLE
 					    current.server.protocol = P_POP3;
@@ -1911,31 +1911,31 @@ yyreduce:
     break;
 
   case 47:
-#line 176 "../rcfile_y.y"
+#line 176 "rcfile_y.y"
                                         {current.server.uidl = FLAG_TRUE;}
 #line 1917 "rcfile_y.c"
     break;
 
   case 48:
-#line 177 "../rcfile_y.y"
+#line 177 "rcfile_y.y"
                                         {current.server.uidl  = FLAG_FALSE;}
 #line 1923 "rcfile_y.c"
     break;
 
   case 49:
-#line 178 "../rcfile_y.y"
+#line 178 "rcfile_y.y"
                                         {current.server.checkalias = FLAG_TRUE;}
 #line 1929 "rcfile_y.c"
     break;
 
   case 50:
-#line 179 "../rcfile_y.y"
+#line 179 "rcfile_y.y"
                                         {current.server.checkalias  = FLAG_FALSE;}
 #line 1935 "rcfile_y.c"
     break;
 
   case 51:
-#line 180 "../rcfile_y.y"
+#line 180 "rcfile_y.y"
                                         {
 					current.server.service = (yyvsp[0].sval);
 					}
@@ -1943,7 +1943,7 @@ yyreduce:
     break;
 
   case 52:
-#line 183 "../rcfile_y.y"
+#line 183 "rcfile_y.y"
                                         {
 					int port = (yyvsp[0].number);
 					char buf[10];
@@ -1954,7 +1954,7 @@ yyreduce:
     break;
 
   case 53:
-#line 189 "../rcfile_y.y"
+#line 189 "rcfile_y.y"
                                         {
 					int port = (yyvsp[0].number);
 					char buf[10];
@@ -1965,25 +1965,25 @@ yyreduce:
     break;
 
   case 54:
-#line 196 "../rcfile_y.y"
+#line 196 "rcfile_y.y"
                         {current.server.interval = (yyvsp[0].number);}
 #line 1971 "rcfile_y.c"
     break;
 
   case 55:
-#line 198 "../rcfile_y.y"
+#line 198 "rcfile_y.y"
                         {current.server.authenticate = (yyvsp[0].proto);}
 #line 1977 "rcfile_y.c"
     break;
 
   case 56:
-#line 200 "../rcfile_y.y"
+#line 200 "rcfile_y.y"
                         {current.server.timeout = (yyvsp[0].number);}
 #line 1983 "rcfile_y.c"
     break;
 
   case 57:
-#line 202 "../rcfile_y.y"
+#line 202 "rcfile_y.y"
                                         {
 					    current.server.envelope = (yyvsp[0].sval);
 					    current.server.envskip = (yyvsp[-1].number);
@@ -1992,7 +1992,7 @@ yyreduce:
     break;
 
   case 58:
-#line 207 "../rcfile_y.y"
+#line 207 "rcfile_y.y"
                                         {
 					    current.server.envelope = (yyvsp[0].sval);
 					    current.server.envskip = 0;
@@ -2001,13 +2001,13 @@ yyreduce:
     break;
 
   case 59:
-#line 212 "../rcfile_y.y"
+#line 212 "rcfile_y.y"
                                         {current.server.qvirtual = (yyvsp[0].sval);}
 #line 2007 "rcfile_y.c"
     break;
 
   case 60:
-#line 213 "../rcfile_y.y"
+#line 213 "rcfile_y.y"
                                         {
 #ifdef CAN_MONITOR
 					interface_parse((yyvsp[0].sval), &current.server);
@@ -2020,7 +2020,7 @@ yyreduce:
     break;
 
   case 61:
-#line 221 "../rcfile_y.y"
+#line 221 "rcfile_y.y"
                                         {
 #ifdef CAN_MONITOR
 					current.server.monitor = (yyvsp[0].sval);
@@ -2033,91 +2033,91 @@ yyreduce:
     break;
 
   case 62:
-#line 229 "../rcfile_y.y"
+#line 229 "rcfile_y.y"
                                         { current.server.plugin = (yyvsp[0].sval); }
 #line 2039 "rcfile_y.c"
     break;
 
   case 63:
-#line 230 "../rcfile_y.y"
+#line 230 "rcfile_y.y"
                                         { current.server.plugout = (yyvsp[0].sval); }
 #line 2045 "rcfile_y.c"
     break;
 
   case 64:
-#line 231 "../rcfile_y.y"
+#line 231 "rcfile_y.y"
                                         {current.server.dns = FLAG_TRUE;}
 #line 2051 "rcfile_y.c"
     break;
 
   case 65:
-#line 232 "../rcfile_y.y"
+#line 232 "rcfile_y.y"
                                         {current.server.dns = FLAG_FALSE;}
 #line 2057 "rcfile_y.c"
     break;
 
   case 66:
-#line 233 "../rcfile_y.y"
+#line 233 "rcfile_y.y"
                                         {current.server.envelope = STRING_DISABLED;}
 #line 2063 "rcfile_y.c"
     break;
 
   case 67:
-#line 234 "../rcfile_y.y"
+#line 234 "rcfile_y.y"
                                         {current.server.tracepolls = FLAG_TRUE;}
 #line 2069 "rcfile_y.c"
     break;
 
   case 68:
-#line 235 "../rcfile_y.y"
+#line 235 "rcfile_y.y"
                                         {current.server.tracepolls = FLAG_FALSE;}
 #line 2075 "rcfile_y.c"
     break;
 
   case 69:
-#line 236 "../rcfile_y.y"
+#line 236 "rcfile_y.y"
                                         {current.server.badheader = BHACCEPT;}
 #line 2081 "rcfile_y.c"
     break;
 
   case 70:
-#line 237 "../rcfile_y.y"
+#line 237 "rcfile_y.y"
                                         {current.server.badheader = BHREJECT;}
 #line 2087 "rcfile_y.c"
     break;
 
   case 71:
-#line 240 "../rcfile_y.y"
+#line 240 "rcfile_y.y"
                                         {record_current(); user_reset();}
 #line 2093 "rcfile_y.c"
     break;
 
   case 73:
-#line 244 "../rcfile_y.y"
+#line 244 "rcfile_y.y"
                                         {record_current(); user_reset();}
 #line 2099 "rcfile_y.c"
     break;
 
   case 74:
-#line 245 "../rcfile_y.y"
+#line 245 "rcfile_y.y"
                                         {record_current(); user_reset();}
 #line 2105 "rcfile_y.c"
     break;
 
   case 76:
-#line 251 "../rcfile_y.y"
+#line 251 "rcfile_y.y"
                                         {current.remotename = (yyvsp[0].sval);}
 #line 2111 "rcfile_y.c"
     break;
 
   case 78:
-#line 253 "../rcfile_y.y"
+#line 253 "rcfile_y.y"
                                         {current.remotename = (yyvsp[-1].sval);}
 #line 2117 "rcfile_y.c"
     break;
 
   case 85:
-#line 268 "../rcfile_y.y"
+#line 268 "rcfile_y.y"
                                         {if (0 == strcmp((yyvsp[0].sval), "*")) {
 					      current.wildcard = TRUE;
 					  } else {
@@ -2128,49 +2128,49 @@ yyreduce:
     break;
 
   case 86:
-#line 274 "../rcfile_y.y"
+#line 274 "rcfile_y.y"
                                         {save_str_pair(&current.localnames, (yyvsp[-2].sval), (yyvsp[0].sval)); free((yyvsp[-2].sval)); free((yyvsp[0].sval));}
 #line 2134 "rcfile_y.c"
     break;
 
   case 87:
-#line 277 "../rcfile_y.y"
+#line 277 "rcfile_y.y"
                                         {save_str(&current.mailboxes,(yyvsp[0].sval),0); free((yyvsp[0].sval));}
 #line 2140 "rcfile_y.c"
     break;
 
   case 88:
-#line 278 "../rcfile_y.y"
+#line 278 "rcfile_y.y"
                                         {save_str(&current.mailboxes,(yyvsp[0].sval),0); free((yyvsp[0].sval));}
 #line 2146 "rcfile_y.c"
     break;
 
   case 89:
-#line 281 "../rcfile_y.y"
+#line 281 "rcfile_y.y"
                                         {save_str(&current.smtphunt, (yyvsp[0].sval),TRUE); free((yyvsp[0].sval));}
 #line 2152 "rcfile_y.c"
     break;
 
   case 90:
-#line 282 "../rcfile_y.y"
+#line 282 "rcfile_y.y"
                                         {save_str(&current.smtphunt, (yyvsp[0].sval),TRUE); free((yyvsp[0].sval));}
 #line 2158 "rcfile_y.c"
     break;
 
   case 91:
-#line 285 "../rcfile_y.y"
+#line 285 "rcfile_y.y"
                                         {save_str(&current.domainlist, (yyvsp[0].sval),TRUE); free((yyvsp[0].sval));}
 #line 2164 "rcfile_y.c"
     break;
 
   case 92:
-#line 286 "../rcfile_y.y"
+#line 286 "rcfile_y.y"
                                         {save_str(&current.domainlist, (yyvsp[0].sval),TRUE); free((yyvsp[0].sval));}
 #line 2170 "rcfile_y.c"
     break;
 
   case 93:
-#line 290 "../rcfile_y.y"
+#line 290 "rcfile_y.y"
                         {
 			    struct idlist *id;
 			    id = save_str(&current.antispam,STRING_DUMMY,0);
@@ -2180,7 +2180,7 @@ yyreduce:
     break;
 
   case 94:
-#line 296 "../rcfile_y.y"
+#line 296 "rcfile_y.y"
                         {
 			    struct idlist *id;
 			    id = save_str(&current.antispam,STRING_DUMMY,0);
@@ -2190,133 +2190,133 @@ yyreduce:
     break;
 
   case 99:
-#line 308 "../rcfile_y.y"
+#line 308 "rcfile_y.y"
                                         {current.remotename  = (yyvsp[-1].sval);}
 #line 2196 "rcfile_y.c"
     break;
 
   case 100:
-#line 309 "../rcfile_y.y"
+#line 309 "rcfile_y.y"
                                         {current.password    = (yyvsp[0].sval);}
 #line 2202 "rcfile_y.c"
     break;
 
   case 104:
-#line 313 "../rcfile_y.y"
+#line 313 "rcfile_y.y"
                                         {current.smtpaddress = (yyvsp[0].sval);}
 #line 2208 "rcfile_y.c"
     break;
 
   case 105:
-#line 314 "../rcfile_y.y"
+#line 314 "rcfile_y.y"
                                         {current.smtpname =    (yyvsp[0].sval);}
 #line 2214 "rcfile_y.c"
     break;
 
   case 107:
-#line 316 "../rcfile_y.y"
+#line 316 "rcfile_y.y"
                                         {current.mda         = (yyvsp[0].sval);}
 #line 2220 "rcfile_y.c"
     break;
 
   case 108:
-#line 317 "../rcfile_y.y"
+#line 317 "rcfile_y.y"
                                         {current.bsmtp       = prependdir ((yyvsp[0].sval), rcfiledir); free((yyvsp[0].sval));}
 #line 2226 "rcfile_y.c"
     break;
 
   case 109:
-#line 318 "../rcfile_y.y"
+#line 318 "rcfile_y.y"
                                         {current.listener    = LMTP_MODE;}
 #line 2232 "rcfile_y.c"
     break;
 
   case 110:
-#line 319 "../rcfile_y.y"
+#line 319 "rcfile_y.y"
                                         {current.preconnect  = (yyvsp[0].sval);}
 #line 2238 "rcfile_y.c"
     break;
 
   case 111:
-#line 320 "../rcfile_y.y"
+#line 320 "rcfile_y.y"
                                         {current.postconnect = (yyvsp[0].sval);}
 #line 2244 "rcfile_y.c"
     break;
 
   case 112:
-#line 322 "../rcfile_y.y"
+#line 322 "rcfile_y.y"
                                         {current.keep        = FLAG_TRUE;}
 #line 2250 "rcfile_y.c"
     break;
 
   case 113:
-#line 323 "../rcfile_y.y"
+#line 323 "rcfile_y.y"
                                         {current.flush       = FLAG_TRUE;}
 #line 2256 "rcfile_y.c"
     break;
 
   case 114:
-#line 324 "../rcfile_y.y"
+#line 324 "rcfile_y.y"
                                         {current.limitflush  = FLAG_TRUE;}
 #line 2262 "rcfile_y.c"
     break;
 
   case 115:
-#line 325 "../rcfile_y.y"
+#line 325 "rcfile_y.y"
                                         {current.fetchall    = FLAG_TRUE;}
 #line 2268 "rcfile_y.c"
     break;
 
   case 116:
-#line 326 "../rcfile_y.y"
+#line 326 "rcfile_y.y"
                                         {current.rewrite     = FLAG_TRUE;}
 #line 2274 "rcfile_y.c"
     break;
 
   case 117:
-#line 327 "../rcfile_y.y"
+#line 327 "rcfile_y.y"
                                         {current.forcecr     = FLAG_TRUE;}
 #line 2280 "rcfile_y.c"
     break;
 
   case 118:
-#line 328 "../rcfile_y.y"
+#line 328 "rcfile_y.y"
                                         {current.stripcr     = FLAG_TRUE;}
 #line 2286 "rcfile_y.c"
     break;
 
   case 119:
-#line 329 "../rcfile_y.y"
+#line 329 "rcfile_y.y"
                                         {current.pass8bits   = FLAG_TRUE;}
 #line 2292 "rcfile_y.c"
     break;
 
   case 120:
-#line 330 "../rcfile_y.y"
+#line 330 "rcfile_y.y"
                                         {current.dropstatus  = FLAG_TRUE;}
 #line 2298 "rcfile_y.c"
     break;
 
   case 121:
-#line 331 "../rcfile_y.y"
+#line 331 "rcfile_y.y"
                                         {current.dropdelivered = FLAG_TRUE;}
 #line 2304 "rcfile_y.c"
     break;
 
   case 122:
-#line 332 "../rcfile_y.y"
+#line 332 "rcfile_y.y"
                                         {current.mimedecode  = FLAG_TRUE;}
 #line 2310 "rcfile_y.c"
     break;
 
   case 123:
-#line 333 "../rcfile_y.y"
+#line 333 "rcfile_y.y"
                                         {current.idle        = FLAG_TRUE;}
 #line 2316 "rcfile_y.c"
     break;
 
   case 124:
-#line 335 "../rcfile_y.y"
+#line 335 "rcfile_y.y"
                                         {
 #ifdef SSL_ENABLE
 		    current.use_ssl = FLAG_TRUE;
@@ -2328,181 +2328,181 @@ yyreduce:
     break;
 
   case 125:
-#line 342 "../rcfile_y.y"
+#line 342 "rcfile_y.y"
                                         {current.sslkey = prependdir ((yyvsp[0].sval), rcfiledir); free((yyvsp[0].sval));}
 #line 2334 "rcfile_y.c"
     break;
 
   case 126:
-#line 343 "../rcfile_y.y"
+#line 343 "rcfile_y.y"
                                         {current.sslcert = prependdir ((yyvsp[0].sval), rcfiledir); free((yyvsp[0].sval));}
 #line 2340 "rcfile_y.c"
     break;
 
   case 127:
-#line 344 "../rcfile_y.y"
+#line 344 "rcfile_y.y"
                                         {current.sslproto = (yyvsp[0].sval);}
 #line 2346 "rcfile_y.c"
     break;
 
   case 128:
-#line 345 "../rcfile_y.y"
+#line 345 "rcfile_y.y"
                                         {current.sslcertck = FLAG_TRUE;}
 #line 2352 "rcfile_y.c"
     break;
 
   case 129:
-#line 346 "../rcfile_y.y"
+#line 346 "rcfile_y.y"
                                         {current.sslcertfile = prependdir((yyvsp[0].sval), rcfiledir); free((yyvsp[0].sval));}
 #line 2358 "rcfile_y.c"
     break;
 
   case 130:
-#line 347 "../rcfile_y.y"
+#line 347 "rcfile_y.y"
                                         {current.sslcertpath = prependdir((yyvsp[0].sval), rcfiledir); free((yyvsp[0].sval));}
 #line 2364 "rcfile_y.c"
     break;
 
   case 131:
-#line 348 "../rcfile_y.y"
+#line 348 "rcfile_y.y"
                                         {current.sslcommonname = (yyvsp[0].sval);}
 #line 2370 "rcfile_y.c"
     break;
 
   case 132:
-#line 349 "../rcfile_y.y"
+#line 349 "rcfile_y.y"
                                         {current.sslfingerprint = (yyvsp[0].sval);}
 #line 2376 "rcfile_y.c"
     break;
 
   case 133:
-#line 351 "../rcfile_y.y"
+#line 351 "rcfile_y.y"
                                         {current.keep        = FLAG_FALSE;}
 #line 2382 "rcfile_y.c"
     break;
 
   case 134:
-#line 352 "../rcfile_y.y"
+#line 352 "rcfile_y.y"
                                         {current.flush       = FLAG_FALSE;}
 #line 2388 "rcfile_y.c"
     break;
 
   case 135:
-#line 353 "../rcfile_y.y"
+#line 353 "rcfile_y.y"
                                         {current.limitflush  = FLAG_FALSE;}
 #line 2394 "rcfile_y.c"
     break;
 
   case 136:
-#line 354 "../rcfile_y.y"
+#line 354 "rcfile_y.y"
                                         {current.fetchall    = FLAG_FALSE;}
 #line 2400 "rcfile_y.c"
     break;
 
   case 137:
-#line 355 "../rcfile_y.y"
+#line 355 "rcfile_y.y"
                                         {current.rewrite     = FLAG_FALSE;}
 #line 2406 "rcfile_y.c"
     break;
 
   case 138:
-#line 356 "../rcfile_y.y"
+#line 356 "rcfile_y.y"
                                         {current.forcecr     = FLAG_FALSE;}
 #line 2412 "rcfile_y.c"
     break;
 
   case 139:
-#line 357 "../rcfile_y.y"
+#line 357 "rcfile_y.y"
                                         {current.stripcr     = FLAG_FALSE;}
 #line 2418 "rcfile_y.c"
     break;
 
   case 140:
-#line 358 "../rcfile_y.y"
+#line 358 "rcfile_y.y"
                                         {current.pass8bits   = FLAG_FALSE;}
 #line 2424 "rcfile_y.c"
     break;
 
   case 141:
-#line 359 "../rcfile_y.y"
+#line 359 "rcfile_y.y"
                                         {current.dropstatus  = FLAG_FALSE;}
 #line 2430 "rcfile_y.c"
     break;
 
   case 142:
-#line 360 "../rcfile_y.y"
+#line 360 "rcfile_y.y"
                                         {current.dropdelivered = FLAG_FALSE;}
 #line 2436 "rcfile_y.c"
     break;
 
   case 143:
-#line 361 "../rcfile_y.y"
+#line 361 "rcfile_y.y"
                                         {current.mimedecode  = FLAG_FALSE;}
 #line 2442 "rcfile_y.c"
     break;
 
   case 144:
-#line 362 "../rcfile_y.y"
+#line 362 "rcfile_y.y"
                                         {current.idle        = FLAG_FALSE;}
 #line 2448 "rcfile_y.c"
     break;
 
   case 145:
-#line 364 "../rcfile_y.y"
+#line 364 "rcfile_y.y"
                                         {current.use_ssl     = FLAG_FALSE;}
 #line 2454 "rcfile_y.c"
     break;
 
   case 146:
-#line 365 "../rcfile_y.y"
+#line 365 "rcfile_y.y"
                                         {current.sslcertck   = FLAG_FALSE;}
 #line 2460 "rcfile_y.c"
     break;
 
   case 147:
-#line 367 "../rcfile_y.y"
+#line 367 "rcfile_y.y"
                                         {current.limit       = NUM_VALUE_IN((yyvsp[0].number));}
 #line 2466 "rcfile_y.c"
     break;
 
   case 148:
-#line 368 "../rcfile_y.y"
+#line 368 "rcfile_y.y"
                                         {current.warnings    = NUM_VALUE_IN((yyvsp[0].number));}
 #line 2472 "rcfile_y.c"
     break;
 
   case 149:
-#line 369 "../rcfile_y.y"
+#line 369 "rcfile_y.y"
                                         {current.fetchlimit  = NUM_VALUE_IN((yyvsp[0].number));}
 #line 2478 "rcfile_y.c"
     break;
 
   case 150:
-#line 370 "../rcfile_y.y"
+#line 370 "rcfile_y.y"
                                         {current.fetchsizelimit = NUM_VALUE_IN((yyvsp[0].number));}
 #line 2484 "rcfile_y.c"
     break;
 
   case 151:
-#line 371 "../rcfile_y.y"
+#line 371 "rcfile_y.y"
                                         {current.fastuidl    = NUM_VALUE_IN((yyvsp[0].number));}
 #line 2490 "rcfile_y.c"
     break;
 
   case 152:
-#line 372 "../rcfile_y.y"
+#line 372 "rcfile_y.y"
                                         {current.batchlimit  = NUM_VALUE_IN((yyvsp[0].number));}
 #line 2496 "rcfile_y.c"
     break;
 
   case 153:
-#line 373 "../rcfile_y.y"
+#line 373 "rcfile_y.y"
                                         {current.expunge     = NUM_VALUE_IN((yyvsp[0].number));}
 #line 2502 "rcfile_y.c"
     break;
 
   case 154:
-#line 375 "../rcfile_y.y"
+#line 375 "rcfile_y.y"
                                         {current.properties  = (yyvsp[0].sval);}
 #line 2508 "rcfile_y.c"
     break;
@@ -2702,7 +2702,7 @@ yyreturn:
   return yyresult;
 }
 
-#line 377 "../rcfile_y.y"
+#line 377 "rcfile_y.y"
 
 
 /* lexer interface */
