@@ -254,7 +254,7 @@ extern int yydebug;
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 union YYSTYPE
 {
-#line 57 "../rcfile_y.y"
+#line 57 "rcfile_y.y"
 
   int proto;
   int number;
